================
OpenStack Cinder
================

.. image:: https://governance.openstack.org/tc/badges/cinder.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

OpenStack Cinder is a storage service for an open cloud computing service.

You can learn more about Cinder at:

* `Wiki <https://wiki.openstack.org/Cinder/>`__
* `Developer Docs <https://docs.openstack.org/cinder/latest/>`__
* `Blueprints <https://blueprints.launchpad.net/cinder/>`__
* `Release notes <https://docs.openstack.org/releasenotes/cinder/>`__
* `Design specifications <https://specs.openstack.org/openstack/cinder-specs/>`__

Getting Started
---------------

If you'd like to run from the master branch, you can clone the git repo:

    git clone https://opendev.org/openstack/cinder

If you'd like to contribute, please see the information in
`CONTRIBUTING.rst <https://opendev.org/openstack/cinder/src/branch/master/CONTRIBUTING.rst>`_

You can raise bugs on `Launchpad <https://bugs.launchpad.net/cinder>`__

Python client
-------------
`Python Cinderclient <https://opendev.org/openstack/python-cinderclient>`__
